Citation
========

If you use PyRCN, please cite the following publication:

.. code-block:: latex

   @INPROCEEDINGS{src:Steiner-20c,  
       author={Peter Steiner and Azarakhsh Jalalvand and Simon Stone Peter Birkholz},  
       booktitle={2020 25th International Conference on Pattern Recognition (ICPR)},   
       title={PyRCN: Exploration and Application of ESNs},  
       year={2020},  
       note={submitted},
   }
